1. Go to mapshaper.org
2. Load your region's `GeoJSON`. In this example, we use the `GeoJSON` of Uttar Pradesh.
3. Activate simplify view (top right, `Simplify` option). You can pick from one of the listed algorithms and a percentage level to simplify the map. Choose a percentage level that doesn't distort the map.
4. Export the simplified file (top right, `Export` option)

The exported file will be noticeably different in size.